GalleryPhotoViewWrapper class

Inheritance

Constructors

GalleryPhotoViewWrapper({Key? key, LoadingBuilder? loadingBuilder, BoxDecoration? backgroundDecoration, dynamic minScale, dynamic maxScale, int? initialIndex, List<String>? galleryItems, List<ImageModel>? mediaItems, List<String>? captions, Axis scrollDirection = Axis.horizontal, Map<String, String>? headers, bool enableSave = true, bool autoPlay = true})

Properties

autoPlay → bool
final
backgroundDecoration → BoxDecoration?
final
captions → List<String>?
final
enableSave → bool
final
galleryItems → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>?
final
initialIndex → int?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingBuilder → LoadingBuilder?
final
maxScale → dynamic
final
mediaItems → List<ImageModel>?
final
minScale → dynamic
final
pageController → PageController
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → Axis
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited