ImageModel class

Constructors

ImageModel({required String imageUrl, String? caption})
const
ImageModel.video({required String videoUrl, String? caption})
const

Properties

caption → String?
final
hashCode → int
The hash code for this object.
no setterinherited
imageUrl → String
final
isVideo → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceUrl → String
no setter
videoUrl → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited