MultiImageViewer class

Inheritance

Constructors

MultiImageViewer({Key? key, required List<ImageModel> images, Color backgroundColor = Colors.black87, TextStyle textStyle = const TextStyle(fontSize: 30, color: Colors.white), double height = 216, double? width, Map<String, String>? networkImageHeaders, bool enableSave = true, bool autoPlay = true, double gap = 2, Radius radius = const Radius.circular(5)})
const

Properties

autoPlay → bool
Responsible for auto playing videos.
final
backgroundColor → Color
Color of the background image.
final
enableSave → bool
Responsible for displaying download icon button
final
gap → double
Gap between Images in px
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
Height of the image(s).
final
images → List<ImageModel>
List<ImageModel> of media and captions to display.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
networkImageHeaders → Map<String, String>?
Headers for network image and video requests.
final
radius → Radius
Border Radius for edge corners
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle
Color for the textStyle
final
width → double?
Width of the image(s).
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited